@@ -48,22 +48,24 @@ class NxPyDocs():
                 self.command = single_command
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                if self.repo:
-                    self.clone()
                 if self.filetype:
-                    self.pick_filetype(parsed_json)
                     if self.repo:
+                        self.clone()
+                        self.pick_filetype(parsed_json)
                         self.send_to_repo()
+                    else:
+                        self.pick_filetype(parsed_json)
         else:
             if self.command in self.supported_templates:
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                if self.repo:
-                    self.clone()                
                 if self.filetype:
-                    self.pick_filetype(parsed_json)
                     if self.repo:
+                        self.clone()
+                        self.pick_filetype(parsed_json)
                         self.send_to_repo()
+                    else: 
+                        self.pick_filetype(parsed_json)
                 else:
                     click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
             else:
@@ -162,9 +164,11 @@ class NxPyDocs():
         self.mindmap_file(parsed_json)
 
     def clone(self):
-        os.system("git clone %s ." % self.repo)
+        os.system("git clone %s nxpydocs" % self.repo)
+        os.system("cd nxpydocs")           
 
-    def send_to_repo(self):       
+    def send_to_repo(self):
+        os.system("git clone %s" % self.repo)
         os.system("git add *")
         os.system("git commit -am 'nxpydocs generated this commit")
         os.system("git push")
